===========================================
COBalD - the Opportunistic Balancing Deamon
===========================================

This is a **draft** for a feedback based balancing system for providing opportunistic resources.
